@@ -8,14 +8,16 @@
 #include "collectionselection.h"
 #include "utils.h"
 
+#include <Akonadi/CollectionUtils>
+
 #include <QItemSelectionModel>
 
 using namespace CalendarSupport;
 
-class Q_DECL_HIDDEN CollectionSelection::Private
+class CalendarSupport::CollectionSelectionPrivate
 {
 public:
-    explicit Private(QItemSelectionModel *model_)
+    explicit CollectionSelectionPrivate(QItemSelectionModel *model_)
         : model(model_)
     {
     }
@@ -25,15 +27,12 @@ public:
 
 CollectionSelection::CollectionSelection(QItemSelectionModel *selectionModel, QObject *parent)
     : QObject(parent)
-    , d(new Private(selectionModel))
+    , d(new CollectionSelectionPrivate(selectionModel))
 {
     connect(selectionModel, &QItemSelectionModel::selectionChanged, this, &CollectionSelection::slotSelectionChanged);
 }
 
-CollectionSelection::~CollectionSelection()
-{
-    delete d;
-}
+CollectionSelection::~CollectionSelection() = default;
 
 QItemSelectionModel *CollectionSelection::model() const
 {
@@ -61,7 +60,7 @@ Akonadi::Collection::List CollectionSelection::selectedCollections() const
     const QModelIndexList selectedIndexes = d->model->selectedIndexes();
     selected.reserve(selectedIndexes.count());
     for (const QModelIndex &idx : selectedIndexes) {
-        selected.append(collectionFromIndex(idx));
+        selected.append(Akonadi::CollectionUtils::fromIndex(idx));
     }
     return selected;
 }
